changeset 755:f3aeb0b47eff dev

comment improvement: vissim time is multiplied to get integers similar to frame numbers
author Nicolas Saunier <nicolas.saunier@polymtl.ca>
date Fri, 30 Oct 2015 14:15:03 -0400
parents 782e8fd3672c
children a73f43aac00e
files python/storage.py
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/python/storage.py	Thu Oct 29 16:31:23 2015 -0400
+++ b/python/storage.py	Fri Oct 30 14:15:03 2015 -0400
@@ -763,9 +763,9 @@
 
 def loadTrajectoriesFromVissimFile(filename, simulationStepsPerTimeUnit, objectNumbers = None, warmUpLastInstant = None, usePandas = False, nDecimals = 2, lowMemory = True):
     '''Reads data from VISSIM .fzp trajectory file
-    simulationStepsPerTimeUnit is the number of simulation steps per unit of time used by VISSIM
-    for example, there seems to be 5 simulation steps per simulated second in VISSIM, 
-    so simulationStepsPerTimeUnit should be 5, 
+    simulationStepsPerTimeUnit is the number of simulation steps per unit of time used by VISSIM (second)
+    for example, there seems to be 10 simulation steps per simulated second in VISSIM, 
+    so simulationStepsPerTimeUnit should be 10, 
     so that all times correspond to the number of the simulation step (and can be stored as integers)
     
     Objects positions will be considered only after warmUpLastInstant